@@ -10,11 +10,11 @@ setMethod("log", signature(x="SpatRaster"),
     function(x, base=exp(1)){
 		opt <- spatOptions()
 		if (base == exp(1)) {
-			x@ptr <- x@ptr$math("log", opt)
+			x@pntr <- x@pntr$math("log", opt)
 		} else if (base == 2) {
-			x@ptr <- x@ptr$math("log2", opt)
+			x@pntr <- x@pntr$math("log2", opt)
 		} else if (base == 10) {
-			x@ptr <- x@ptr$math("log10", opt)
+			x@pntr <- x@pntr$math("log10", opt)
 		} else {
 			x <- app(x, function(i) log(i, base))
 		}
@@ -29,11 +29,11 @@ setMethod("Math", signature(x="SpatRaster"),
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
 		if (substr(oper, 1, 3) == "cum") {
-			x@ptr <- x@ptr$cum(substr(oper, 4, 10), FALSE, opt)
+			x@pntr <- x@pntr$cum(substr(oper, 4, 10), FALSE, opt)
 		} else if (oper %in% c("acos", "acosh", "asin", "asinh", "atan", "atanh", "cos", "cosh", "cospi", "sin", "sinh", "sinpi", "tan", "tanh", "tanpi")) {
-			x@ptr <- x@ptr$trig(oper, opt)
+			x@pntr <- x@pntr$trig(oper, opt)
 		} else {
-			x@ptr <- x@ptr$math(oper, opt)
+			x@pntr <- x@pntr$math(oper, opt)
 		}
 		messages(x, oper)
 	}
@@ -49,12 +49,12 @@ setMethod("math", signature(x="SpatRaster"),
 		fun = fun[1]
 		opt <- spatOptions(filename, overwrite, ...)
 		if (substr(fun, 1, 3) == "cum") {
-			x@ptr <- x@ptr$cum(substr(fun, 4, 10), FALSE, "", FALSE)
+			x@pntr <- x@pntr$cum(substr(fun, 4, 10), FALSE, "", FALSE)
 		} else if (fun %in% c("acos", "acosh", "asin", "asinh", "atan", "atanh", "cos", "cosh", "cospi", "sin", "sinh", "sinpi", "tan", "tanh", "tanpi")) {
-			x@ptr <- x@ptr$trig(fun, opt)
-		} else if (fun %in% c("abs", "sign", "sqrt", "ceiling", "floor", "trunc", "log", "log10", "log2")) {		x@ptr <- x@ptr$math(fun, opt)
+			x@pntr <- x@pntr$trig(fun, opt)
+		} else if (fun %in% c("abs", "sign", "sqrt", "ceiling", "floor", "trunc", "log", "log10", "log2")) {		x@pntr <- x@pntr$math(fun, opt)
 		} else if (fun %in% c("round", "signif")) {
-			x@ptr <- x@ptr$math2(fun, digits, opt)
+			x@pntr <- x@pntr$math2(fun, digits, opt)
 		} else {
 			error("math", "unknown function")
 		}
@@ -68,7 +68,7 @@ setMethod("Math2", signature(x="SpatRaster"),
     function(x, digits=0){
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
-		x@ptr <- x@ptr$math2(oper, digits, opt)
+		x@pntr <- x@pntr$math2(oper, digits, opt)
 		messages(x, oper)
 	}
 )
@@ -78,9 +78,9 @@ setMethod("Math", signature(x="SpatExtent"),
     function(x){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "floor") {
-			x@ptr <- x@ptr$floor()
+			x@pntr <- x@pntr$floor()
 		} else if (oper == "ceiling") {
-			x@ptr <- x@ptr$ceil()
+			x@pntr <- x@pntr$ceil()
 		} else {
 			error(oper, "not implemented for SpatExtent")
 		}
@@ -95,7 +95,7 @@ setMethod("Math2", signature(x="SpatExtent"),
     function(x, digits=0){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "round") {
-			x@ptr <- x@ptr$round(digits)
+			x@pntr <- x@pntr$round(digits)
 			if (!is.valid(x)) {
 				error(oper, "invalid extent")
 			}
@@ -110,7 +110,7 @@ setMethod("Math2", signature(x="SpatVector"),
     function(x, digits=4){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "round") {
-			x@ptr <- x@ptr$round(digits)
+			x@pntr <- x@pntr$round(digits)
 			return(x)
 		} else {
 			error(oper, "not implemented for SpatVector")
