@@ -171,7 +171,11 @@ setMethod("pairs", signature(x="SpatRaster"),
 
 
 .halo <- function(x, y=NULL, labels, col="black", hc="white", hw=0.1, ... ) {
-	xy <- grDevices::xy.coords(x, y)
+	if (!is.null(y)) { # recycle
+		xy <- grDevices::xy.coords(cbind(x, y))
+	} else {
+		xy <- grDevices::xy.coords(x, y)
+	}
 	hw <- hw[1]
 	xo <- hw * graphics::strwidth("A")
 	yo <- hw * graphics::strheight("A")
@@ -191,7 +195,7 @@ halo <- function(x, y=NULL, labels, col="black", hc="white", hw=0.1, ... ) {
 
 
 setMethod("text", signature(x="SpatRaster"),
-	function(x, labels, digits=0, halo=FALSE, hc="white", hw=0.1, ...) {
+	function(x, labels, digits=0, halo=FALSE, hc="white", hw=0.1, jitter=0, ...) {
 		if (missing(labels)) {
 			labels <- 1
 		}
@@ -210,11 +214,20 @@ setMethod("text", signature(x="SpatRaster"),
 			p <- as.points(x, values=FALSE, na.rm=FALSE)
 		}
 		xy <- geom(p)[, c("x", "y"), drop=FALSE]
+        if (isTRUE(jitter > 0)) {
+			xy <- jitter(xy, factor = jitter)
+		}
 		if (is.factor(labels)) {
 			labels <- substr(as.character(labels), 1, max(1, digits))
 		} else if (is.numeric(labels)) {
 			labels <- as.character(round(labels, digits=digits) )
 		}
+		if (length(labels) < nrow(xy)) {
+			labels <- rep(labels, nrow(xy))
+		}
+#		if (!overlap) {
+#			xy <- getLabelXY(xy, labels, cex)
+#		}
 		if (halo && (isTRUE(hw > 0))) {
 			.halo(xy[,1], xy[,2], labels, hc=hc, hw=hw, ...)
 		} else {
@@ -225,7 +238,7 @@ setMethod("text", signature(x="SpatRaster"),
 
 
 setMethod("text", signature(x="SpatVector"),
-	function(x, labels, halo=FALSE, inside=FALSE, hc="white", hw=0.1, ...) {
+	function(x, labels, halo=FALSE, inside=FALSE, hc="white", hw=0.1, jitter=0, ...) {
 		if (missing(labels)) {
 			labels <- 1:nrow(x)
 		} else if (length(labels) == 1) {
@@ -242,6 +255,9 @@ setMethod("text", signature(x="SpatVector"),
 			}
 		}
 		xy <- geom(centroids(x, inside=inside))[,c("x","y"),drop=FALSE]
+        if (isTRUE(jitter > 0)) {
+			xy <- jitter(xy, factor = jitter)
+		}
 		if (halo && (isTRUE(hw > 0))) {
 			.halo(xy[,1], xy[,2], labels, hc=hc, hw=hw, ...)
 		} else {
@@ -327,7 +343,7 @@ shade <- function(slope, aspect, angle=45, direction=0, normalize=FALSE, filenam
 map.pal <- function(name, n=50, ...) { 
 	n <- round(n)
 	if (n < 1) {
-		error("map.pal", "n should be > 0")	
+		error("map.pal", "n should be >= 1")	
 	}
 	f <- system.file("colors/palettes.rds", package="terra")
 	v <- readRDS(f)
@@ -343,7 +359,8 @@ map.pal <- function(name, n=50, ...) {
 		}
 	} else if (name == "random") {
 		if (n > 433) {
-			error("map.pal", "you cannot get more than 433 random colors")
+			warning("map.pal", "you cannot get > 433 random colors; using n=433 instead")
+			n <- 433
 		}
 		s <- sample(grDevices::colors()[grep('gr(a|e)y', grDevices::colors(), invert = TRUE)], n)
 		rgb(t(grDevices::col2rgb(s))/255)
