@@ -1,32 +1,32 @@
 
-.assume_lonlat <- function(pr) {
-	(pr$usr[1] > -181) && (pr$usr[2] < 181) && (pr$yaxp[1] > -200) && (pr$yaxp[2] < 200)
+..assume_lonlat <- function(pr) {
+	(pr$usr[1] > -300) && (pr$usr[2] < 300) && (pr$yaxp[1] > -200) && (pr$yaxp[2] < 200)
 }
 
 .get_dd <- function(pr, lonlat, d=NULL) {
 	if (lonlat) {
-		lat <- mean(pr$yaxp[1:2])
+		lat <- mean(pr$usr[3:4])
 		if (is.null(d)) {
 			dx <- (pr$usr[2] - pr$usr[1]) / 6
 			d <- as.vector(distance(cbind(0, lat), cbind(dx, lat), TRUE))
-			d <- signif(d / 1000, 2)
+			d <- max(1, 5 * round(d/5000))
 		}
 		p <- cbind(0, lat)
 		dd <- .destPoint(p, d * 1000)
-		dd <- dd[1,1]
+		dd <- c(dd[1,1], d)
 	} else {
 		if (is.null(d)) {
 			d <- (pr$usr[2] - pr$usr[1]) / 6
 			digits <- floor(log10(d)) + 1
 			d <- round(d, -(digits-1))
 		}
-		dd <- d
+		dd <- c(d, d)
 	}
 	dd
 }
 
 .get_xy <- function(xy, dx=0, dy=0, pr, defpos="bottomleft", caller="") {
-    if(is.null(xy)) {
+    if (is.null(xy)) {
 		xy <- defpos
 	}
 	if (!is.character(xy)) {
@@ -116,12 +116,13 @@ add_N <- function(x, y, asp, label, type=0, user="", angle=0, cex=1, srt=0, xpd=
 
 north <- function(xy=NULL, type=1, label="N", angle=0, d, head=0.1, xpd=TRUE, ...) {
 	pr <- graphics::par()
+	pr$usr <- unlist(get.clip()[1:4])
 	pa <- c(pr$usr[2] - pr$usr[1], pr$usr[4] - pr$usr[3])
 	asp <- pa[2]/pa[1]
 	if (missing(d))	{
 		d <- 0.07 * pa[2]
 	}
-	xy <- .get_xy(xy, 0, d, pr, "topright", caller="arrow")
+	xy <- .get_xy(xy, 0, d, pr, "topright", caller="north")
 
 	if (inherits(type, "character")) {
 		usertype <- type
@@ -167,86 +168,144 @@ north <- function(xy=NULL, type=1, label="N", angle=0, d, head=0.1, xpd=TRUE, ..
 	}
 }
 
+draw_box <- function(xy, d, below, labels, box.col, cex=1, ...){
+	h <- graphics::strheight("A", cex=cex)
+	w <- c(graphics::strwidth(labels[1], cex=cex), graphics::strwidth(labels[length(labels)], cex=cex))
+	box.col <- rep(box.col, length.out=2)
+	b <- ifelse(isTRUE(nchar(below) > 1), 3.5, 1.5)
+	e <- c(xy[1]-1.5*w[1], xy[1]+d+w[2], xy[2]-b*h, xy[2]+3*h)
+	polys(vect(ext(e)), col=box.col[1], border=box.col[2], xpd=TRUE)
+}
 
-sbar <- function(d, xy=NULL, type="line", divs=2, below="", lonlat=NULL, label, adj=c(0.5, -1), lwd=2, xpd=TRUE, ...){
+
+add_text <- function(halo=FALSE, ...) {
+	if (halo) {
+		halo(...)
+	} else {
+		text(...)
+	}
+}
+
+
+sbar <- function(d, xy=NULL, type="line", divs=2, below="", lonlat=NULL, labels, adj=c(0.5, -1), lwd=2, xpd=TRUE, ticks=FALSE, scaleby=1, halo=TRUE, col="black", fill=c("black", "white"), border="black", ...){
+
+box=FALSE
+box.col=c("white", "black")
+box.adj=c(0,0,0,0)
 
 	stopifnot(type %in% c("line", "bar"))
 	pr <- graphics::par()
+	clp <- get.clip()
+	pr$usr <- unlist(clp[,1:4])
 	if (is.null(lonlat)) {
-		lonlat <- .assume_lonlat(pr)
+		lonlat <- isTRUE(clp[[5]])
 	}
+	fill <- rep(fill, length.out=2)
+
 
 	if (missing(d)) {
-		label <- NULL
+		labels <- NULL
 		d <- NULL
 	}
 	dd <- .get_dd(pr, lonlat, d)
-	if (is.null(d)) d <- dd
+	d <- dd[2]
+	dd <- dd[1]
+
 	xy <- .get_xy(xy, dd, 0, pr, "bottomleft", caller="sbar")
 
 	if (type == "line") {
-		lines(matrix(c(xy[1], xy[2], xy[1]+dd, xy[2]), byrow=T, nrow=2), lwd=lwd, xpd=xpd, ...)
-		if (missing(label)) {
-			label <- paste(d)
+		if (missing(labels) || is.null(labels)) {
+			ds <- d / scaleby
+			if (divs > 2) {
+				labels <- c(0, round(ds/2, 1), ds)
+			} else {
+				labels <- paste(ds)
+			}
 		}
-		if (is.null(label)) {
-			label <- paste(d)
+		if (box) draw_box(xy, dd, below, labels, box.col, ...)	
+
+
+		if (halo) {
+			lines(matrix(c(xy[1], xy[2], xy[1]+dd, xy[2]), byrow=T, nrow=2), lwd=lwd+1, xpd=xpd, col="white")
 		}
+		lines(matrix(c(xy[1], xy[2], xy[1]+dd, xy[2]), byrow=T, nrow=2), lwd=lwd, xpd=xpd, col=fill[1], ...)
+		
 		if (missing(adj)) {
 			adj <- c(0.5, -0.2-lwd/20 )
 		}
-
-		if (length(label) == 1) label =c("", label, "")
-		text(xy[1], xy[2],labels=label[1], xpd=xpd, adj=adj,...)
-		text(xy[1]+0.5*dd, xy[2],labels=label[2], xpd=xpd, adj=adj,...)
-		text(xy[1]+dd, xy[2],labels=label[3], xpd=xpd, adj=adj,...)
-
-		xy[2] <- xy[2] - dd/10
+		tadd <- 0
+		if (!isFALSE(ticks)) {
+			if (isTRUE(ticks)) {
+				tadd <- dd / (15 * diff(pr$usr[1:2]) / diff(pr$usr[3:4]))
+			} else {
+				tadd <- ticks
+			}
+			if (length(labels) == 1) {
+				xtick <- c(xy[1], xy[1]+dd)
+			} else {
+				xtick <- c(xy[1], xy[1]+dd/2, xy[1]+dd)			
+			}
+			for (i in 1:length(xtick)) {
+				lines(rbind(c(xtick[i], xy[2]), c(xtick[i], xy[2]+tadd)), lwd=ceiling(lwd/2), xpd=TRUE, ...)
+			}
+		}
+		tadd <- max(graphics::strheight("0", cex=1)/5, tadd)
+		if (length(labels) == 1) labels =c("", labels, "")
+		add_text(xy[1]+c(0,dd/2,dd),xy[2]+tadd, labels=labels, xpd=xpd, adj=adj, halo=halo, col=col, ...)
 
 	} else if (type == "bar") {
 		stopifnot(divs > 0)
-
 		if (missing(adj)) {
-			adj <- c(0.5, -1 )
+			adj <- c(0.5, -1)
 		}
 		lwd <- dd / 25
 
 		if (divs==2) {
-			half <- xy[1] + dd / 2
-			graphics::polygon(c(xy[1], xy[1], half, half), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="white", xpd=xpd)
-			graphics::polygon(c(half, half, xy[1]+dd, xy[1]+dd ), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="black", xpd=xpd)
-			if (missing(label)) {
-				label <- c("0", "", d)
-			}
-			if (is.null(label)) {
-				label <- c("0", "", d)
+			if (missing(labels) || is.null(labels)) {
+				labels <- c("0", "", d/scaleby)
 			}
+			if (box) draw_box(xy, dd, below, labels, box.col, ...)	
 
-			text(xy[1], xy[2],labels=label[1], xpd=xpd, adj=adj,...)
-			text(xy[1]+0.5*dd, xy[2],labels=label[2], xpd=xpd, adj=adj,...)
-			text(xy[1]+dd, xy[2],labels=label[3], xpd=xpd, adj=adj,...)
+			half <- xy[1] + dd / 2
+			if (halo) {
+				graphics::polygon(c(xy[1], xy[1], xy[1]+dd, xy[1]+dd), 
+								  c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="white", xpd=xpd, border="white", lwd=3)
+			}
+			
+			graphics::polygon(c(xy[1], xy[1], half, half), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[1], xpd=xpd, border=border)
+			graphics::polygon(c(half, half, xy[1]+dd, xy[1]+dd ), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[2], xpd=xpd, border=border)
+
+			add_text(xy[1], xy[2], labels=labels[1], xpd=xpd, adj=adj, halo=halo, col=col, ...)
+			add_text(xy[1]+0.5*dd, xy[2], labels=labels[2], xpd=xpd, adj=adj, halo=halo, col=col,...)
+			add_text(xy[1]+dd, xy[2], labels=labels[3], xpd=xpd, adj=adj, halo=halo, col=col,...)
 		} else {
+			if (missing(labels) || is.null(labels)) {
+				ds <- d / scaleby
+				labels <- c("0", round(0.5*ds), ds)
+			}
+			if (box) draw_box(xy, dd, below, labels, box.col, ...)	
+
 			q1 <- xy[1] + dd / 4
 			half <- xy[1] + dd / 2
 			q3 <- xy[1] + 3 * dd / 4
 			end <- xy[1] + dd
-			graphics::polygon(c(xy[1], xy[1], q1, q1), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="white", xpd=xpd)
-			graphics::polygon(c(q1, q1, half, half), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="black", xpd=xpd)
-			graphics::polygon(c(half, half, q3, q3 ), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="white", xpd=xpd)
-			graphics::polygon(c(q3, q3, end, end), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col="black", xpd=xpd)
-			if (missing(label)) {
-				label <- c("0", round(0.5*d), d)
-			}
-			if (is.null(label)) {
-				label <- c("0", round(0.5*d), d)
-			}
-			text(xy[1], xy[2], labels=label[1], xpd=xpd, adj=adj, ...)
-			text(half, xy[2], labels=label[2], xpd=xpd, adj=adj,...)
-			text(end, xy[2],labels=label[3], xpd=xpd, adj=adj,...)
+			graphics::polygon(c(xy[1], xy[1], q1, q1), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[1], xpd=xpd, border=border)
+			graphics::polygon(c(q1, q1, half, half), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[2], xpd=xpd, border=border)
+			graphics::polygon(c(half, half, q3, q3 ), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[1], xpd=xpd, border=border)
+			graphics::polygon(c(q3, q3, end, end), c(xy[2], xy[2]+lwd, xy[2]+lwd, xy[2]), col=fill[2], xpd=xpd, border=border)
+			add_text(xy[1], xy[2], labels=labels[1], xpd=xpd, adj=adj, halo=halo, col=col, ...)
+			add_text(half, xy[2], labels=labels[2], xpd=xpd, adj=adj, halo=halo, col=col,...)
+			add_text(end, xy[2],labels=labels[3], xpd=xpd, adj=adj, halo=halo, col=col,...)
 		}
 	}
 	if (below != "") {
 		adj[2] <- -adj[2]
-		text(xy[1]+(0.5*dd), xy[2], xpd=xpd, labels=below, adj=adj,...)
+		if (type == "line") {
+			xy[2] <- xy[2] - graphics::strheight("1")/1.5
+		} else {
+			xy[2] <- xy[2] - graphics::strheight("1")/4		
+		}
+		add_text(xy[1]+(dd/2), xy[2], xpd=xpd, labels=below, adj=adj, halo=halo, col=col, ...)
 	}
 }
+
