@@ -53,16 +53,23 @@ setMethod("subset", signature(x="SpatRaster"),
 		if (negate) subset = -subset
 		subset <- positive_indices(subset, nlyr(x), TRUE, "subset")
 		opt <- spatOptions(filename, overwrite, ...)
-		x@ptr <- x@ptr$subset(subset-1, opt)
+		x@pntr <- x@pntr$subset(subset-1, opt)
 		messages(x, "subset")
 	}
 )
 
 
-
 ## exact matching
 setMethod("$", "SpatRaster",
 	function(x, name) {
+		if ((nlyr(x) == 1) && is.factor(x)) {
+			factnms <- names(cats(x)[[1]])
+			i <- match(name, factnms[-1])
+			if (!is.na(i)) {
+				activeCat(x) <- i		
+				return(x)
+			}
+		}
 		subset(x, name, NSE=FALSE)
 	}
 )
@@ -95,6 +102,7 @@ function(x, i, j) {
 
 setMethod("subset", signature(x="SpatVector"),
 	function(x, subset, select, drop=FALSE, NSE=FALSE) {
+		
  		if (NSE) {
 			d <- as.list(x)
 			# from the subset<data.frame> method
@@ -118,10 +126,17 @@ setMethod("subset", signature(x="SpatVector"),
 				}
 			x <- x[r, v, drop=drop]
 		} else {
-			if (missing(select)) {
-				x <- x[which(as.vector(subset)), drop=drop]
+			if (missing(subset)) subset <- TRUE
+			spatcls <- isTRUE(substr(class(subset)[1], 1, 4) == "Spat")
+			if (spatcls) {
+				x <- x[subset]
+				if (!missing(select)) {
+					x <- x[, select, drop=drop]
+				}
+			} else if (missing(select)) {
+				x <- x[(as.vector(subset)), drop=drop]
 			} else {
-				x <- x[which(as.vector(subset)), select, drop=drop]
+				x <- x[(as.vector(subset)), select, drop=drop]
 			}
 		}
 		#g <- gc()
@@ -144,10 +159,10 @@ setMethod("subset", signature(x="SpatVector"),
 			i <- 0
 		}
 	}
-	x@ptr <- x@ptr$subset_cols(i-1)
+	x@pntr <- x@pntr$subset_cols(i-1)
 	x <- messages(x, "subset")
 	if (drop) {	# drop geometry
-		.getSpatDF(x@ptr$df)
+		.getSpatDF(x@pntr$df)
 	} else {
 		x
 	}
@@ -157,7 +172,7 @@ setMethod("subset", signature(x="SpatVector"),
 setMethod("[", c("SpatVector", "numeric", "missing"),
 function(x, i, j, ... , drop=FALSE) {
 	i <- positive_indices(i, nrow(x), TRUE, "`[`")
-	x@ptr <- x@ptr$subset_rows(i-1)
+	x@pntr <- x@pntr$subset_rows(i-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
@@ -176,7 +191,7 @@ function(x, i, j, drop=FALSE) {
 setMethod("[", c("SpatVector", "logical", "missing"),
 function(x, i, j, drop=FALSE) {
 	i <- which(rep_len(i, nrow(x)))
-	x@ptr <- x@ptr$subset_rows(i-1)
+	x@pntr <- x@pntr$subset_rows(i-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
@@ -189,8 +204,8 @@ setMethod("[", c("SpatVector", "numeric", "numeric"),
 function(x, i, j, drop=FALSE) {
 	i <- positive_indices(i, nrow(x), TRUE, "`[`")
 	j <- positive_indices(j, ncol(x), TRUE, "`[`")
-	p <- x@ptr$subset_rows(i-1)
-	x@ptr <- p$subset_cols(j-1)
+	p <- x@pntr$subset_rows(i-1)
+	x@pntr <- p$subset_cols(j-1)
 	x <- messages(x, "'['")
 	if (drop) {
 		as.data.frame(x)
@@ -203,7 +218,7 @@ function(x, i, j, drop=FALSE) {
 setMethod("[", c("SpatVector", "missing", "numeric"),
 function(x, i, j, drop=FALSE) {
 	j <- positive_indices(j, ncol(x), TRUE, "`[`")
-	x@ptr <- x@ptr$subset_cols(j-1)
+	x@pntr <- x@pntr$subset_cols(j-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
