@@ -619,6 +619,14 @@ SpatRaster SpatRaster::distance(double target, double exclude, bool keepNA, std:
 		return out;
 	}
 
+//	bool guess_lonlat = false;
+//	if (source[0].srs.is_empty() && could_be_lonlat()) {
+//		guess_lonlat = true;
+//		crswarning = "Guessing that the CRS is lon/lat");
+//	}
+//	bool as_lonlat = is_lonlat() || guess_lonlat;
+
+
 	SpatOptions ops(opt);
 	size_t nl = nlyr();
 	if (nl > 1) {
@@ -1870,7 +1878,7 @@ SpatRaster SpatRaster::edges(bool classes, std::string type, unsigned directions
 
 
 
-SpatRaster SpatRaster::buffer(double d, double background, SpatOptions &opt) {
+SpatRaster SpatRaster::buffer(double d, double background, bool include, SpatOptions &opt) {
 
 	SpatRaster out = geometry(1);
 	if (!hasValues()) {
@@ -1900,7 +1908,7 @@ SpatRaster SpatRaster::buffer(double d, double background, SpatOptions &opt) {
 			std::vector<size_t> lyr = {i};
 			SpatRaster r = subset(lyr, ops);
 			ops.names = {nms[i]};
-			r = r.buffer(d, background, ops);
+			r = r.buffer(d, background, include, ops);
 			out.source[i] = r.source[0];
 		}
 		if (!opt.get_filename().empty()) {
@@ -1911,25 +1919,39 @@ SpatRaster SpatRaster::buffer(double d, double background, SpatOptions &opt) {
 
 
 	if (!is_lonlat()) {
+		SpatOptions opt2;
+		if (include) {
+			opt2 = opt;			
+		} else {
+			opt2 = ops;
+		}
 		if (!std::isnan(background)) {
 			out = proximity(NAN, NAN, false, "", true, d, true, ops);
 			if (background == 0) {
-				out = out.isnotnan(false, opt);
+				out = out.isnotnan(false, opt2);
 			} else {
-				out = out.replaceValues({NAN}, {background}, 1, false, NAN, false, opt);
+				out = out.replaceValues({NAN}, {background}, 1, false, NAN, false, opt2);
 			}
 		} else {
-			out = proximity(NAN, NAN, false, "", true, d, true, opt);
+			out = proximity(NAN, NAN, false, "", true, d, true, opt2);
+		}
+		if (!include) {
+			out = out.mask(*this, true, NAN, NAN, opt);						
 		}
 	} else {
 		SpatRaster e = edges(false, "inner", 8, NAN, ops);
 		SpatVector p = e.as_points(false, true, false, ops);
 		p = p.buffer({d}, 10, "", "", NAN, false);
 		p = p.aggregate(true);
-		out = out.rasterize(p, "", {1}, background, false, "", false, false, true, opt);
+		out = out.rasterize(p, "", {1}, background, false, "", false, false, true, ops);
 		if (background == 0) {
 			out.setValueType(3);
 		}
+		if (include) {
+			out = out.mask(*this, true, NAN, 1, opt);
+		} else {
+			out = out.mask(*this, true, NAN, NAN, opt);			
+		}
 		//out = out.disdir_vector_rasterize(p, false, true, false, false, NAN, NAN, "m", ops);
 		//out = out.arith(d, "<=", false, opt);
 	}
