@@ -37,10 +37,15 @@ bool driverSupports(std::string driver, std::string option) {
 }
 
 
-#include "Rcpp.h"
-
 GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, std::string driver, bool append, bool overwrite, std::vector<std::string> options) {
 
+	#if (GDAL_VERSION_MAJOR == 3 && GDAL_VERSION_MINOR >= 11) || (GDAL_VERSION_MAJOR >= 4)
+	if (driver == "Memory") {
+		driver = "MEM";
+	}
+	#endif
+
+
     GDALDataset *poDS = NULL;
 	if (nrow() == 0) {
 		setError("SpatVector has no records to write");
